@@ -99,7 +99,12 @@ impl ErlangPlugin {
 
         let os_ver: String;
         if let Ok(os) = std::env::var("ImageOS") {
-            os_ver = os
+            os_ver = match os.as_str() {
+                "ubuntu24" => "ubuntu-24.04".to_string(),
+                "ubuntu22" => "ubuntu-22.04".to_string(),
+                "ubuntu20" => "ubuntu-20.04".to_string(),
+                _ => os,
+            };
         } else if let Ok(os_release) = &*os_release::OS_RELEASE {
             os_ver = format!("{}-{}", os_release.id, os_release.version_id);
         } else {
@@ -243,6 +248,11 @@ impl ErlangPlugin {
         Ok(Some(tv))
     }
 
+    #[cfg(not(any(linux, macos, windows)))]
+    async fn install_precompiled(&self, ctx: &InstallContext) -> Result<Option<ToolVersion>> {
+        Ok(None)
+    }
+
     async fn install_via_kerl(
         &self,
         _ctx: &InstallContext,
